@@ -1,6 +1,6 @@
 package SPVM::Sys;
 
-our $VERSION = "0.502";
+our $VERSION = "0.503";
 
 1;
 
@@ -424,19 +424,19 @@ The exceptions thrown by he L</"stat"> method could be thrown.
 
 C<static method time : long ();>
 
-Returns the number of non-leap seconds since whatever time the system considers to be the epoch, suitable for feeding to gmtime and localtime. The same as the Perl L<time|https://perldoc.perl.org/functions/time>. 
+Returns the current epoch time.
 
 =head2 localtime
 
 C<static method localtime : L<Sys::Time::Tm|SPVM::Sys::Time::Tm> ($time : long);>
 
-Converts a time as returned by the time function to a L<Sys::Time::Tm|SPVM::Sys::Time::Tm> object with the time analyzed for the local time zone. The same as the Perl L<localtime|https://perldoc.perl.org/functions/localtime>.
+Converts a time to a L<Sys::Time::Tm|SPVM::Sys::Time::Tm> object, and returns it.
 
 =head2 gmtime
 
 C<static method gmtime : L<Sys::Time::Tm|SPVM::Sys::Time::Tm> ($time : long);>
 
-Works just like localtime, but the returned values are localized for the standard Greenwich time zone. The same as the Perl L<gmtime|https://perldoc.perl.org/functions/gmtime>.
+Works just like L</"localtime">, but the returned values are localized for the standard Greenwich time zone.
 
 =head2 process_id
 
@@ -466,24 +466,18 @@ C<static method chdir : void ($path : string);>
 
 Changes the working directory to $path. The same as the Perl L<chdir|https://perldoc.perl.org/functions/chdir> function.
 
-If succeed, returns 1.
-
 =head2 chmod
 
 C<static method chmod : void ($mode :int, $path : string);>
 
 Changes the permissions of a file. The same as the Perl L<chmod|https://perldoc.perl.org/functions/chmod> function.
 
-If succeed, returns 1.
-
 =head2 mkdir
 
 C<static method mkdir : void ($path : string, $mode : int);>
 
 Creates the directory specified by $path and $mode. The same as the Perl L<mkdir|https://perldoc.perl.org/functions/mkdir> function.
 
-If succeed, returns 1.
-
 =head2 umask
 
 C<static method umask : int ($mode : int);>
@@ -496,8 +490,6 @@ C<static method rmdir : void ($path : string);>
 
 Deletes the directory specified by $path. The same as the Perl L<rmdir|https://perldoc.perl.org/functions/rmdir> function.
 
-If succeed, returns 1.
-
 =head2 opendir
 
 C<static method opendir : void ($dh_ref : L<Sys::IO::DirStream|SPVM::Sys::IO::DirStream>[], $dir : string);>
@@ -506,16 +498,12 @@ Calls the L<opendir|SPVM::Sys::IO/"opendir"> method in the L<Sys::Socket|SPVM::S
 
 The return value is set to $dh_ref->[0].
 
-If succeed, returns 1.
-
 =head2 closedir
 
 C<static method closedir : void ($dirp : L<Sys::IO::DirStream|SPVM::Sys::IO::DirStream>);>
 
 Calls the L<closedir|SPVM::Sys::IO/"closedir"> method in the L<Sys::Socket|SPVM::Sys::Socket> class.
 
-If succeed, returns 1.
-
 =head2 close
 
 C<static method close : void ($stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>);>
@@ -530,16 +518,12 @@ C<static method unlink : void ($pathname : string);>
 
 Deletes a file. The same as the Perl L<unlink|https://perldoc.perl.org/functions/unlink> function.
 
-If succeed, returns 1.
-
 =head2 rename
 
 C<static method rename : void ($oldpath : string, $newpath : string);>
 
 Changes the name of a file. The same as the Perl L<rename|https://perldoc.perl.org/functions/rename> function.
 
-If succeed, returns 1.
-
 =head2 readlink
 
 C<static method readlink : int ($file : string);>
@@ -552,8 +536,6 @@ C<static method symlink : int ($oldpath : string, $newpath : string);>
 
 Creates a $newpath symbolically linked to $oldpath. The same as the Perl L<symlink|https://perldoc.perl.org/functions/symlink> function.
 
-If succeed, returns 1.
-
 =head2 sleep
 
 C<static method sleep : int ($seconds : int);>
@@ -570,7 +552,7 @@ Calls the L<ioctl|SPVM::Sys::Ioctl/"ioctl"> method in the L<Sys::Ioctl|SPVM::Sys
 
 =head2 select
 
-C<static method select : int ($readfds : L<Sys::Select::Fd_set|SPVM::Sys::Select::Fd_set>, $writefds : L<Sys::Select::Fd_set|SPVM::Sys::Select::Fd_set>, $exceptfds : L<Sys::Select::Fd_set|SPVM::Sys::Select::Fd_set>, $timeout : L<Sys::Time::Timeval|SPVM::Sys::Time::Timeval>);>
+C<static method select : int ($readfds : L<Sys::Select::Fd_set|SPVM::Sys::Select::Fd_set>, $writefds : L<Sys::Select::Fd_set|SPVM::Sys::Select::Fd_set>, $exceptfds : L<Sys::Select::Fd_set|SPVM::Sys::Select::Fd_set>, $timeout : double);>
 
 Calls the L<select|SPVM::Sys::Select/"select"> method in the L<Sys::Select|SPVM::Sys::Select> class with $ndfs set to 1024.
 
@@ -582,16 +564,12 @@ The next argument $addrlen is set to the size of $addr.
 
 Calls the L<bind|SPVM::Sys::Socket/"bind"> method in the L<Sys::Socket|SPVM::Sys::Socket> class with $addrlen.
 
-If succeed, returns 1.
-
 =head2 listen
 
 C<static method listen : void ($sockfd : int, $backlog : int);>
 
 Calls the L<listen|SPVM::Sys::Socket/"listen"> method in the L<Sys::Socket|SPVM::Sys::Socket> class.
 
-If succeed, returns 1.
-
 =head2 accept
 
 C<static method accept : L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr> ($new_sockfd_ref : int*, $sockfd : int);>
@@ -611,8 +589,6 @@ The next argument $addrlen is set to the size of $addr.
 
 Calls the L<connect|SPVM::Sys::Socket/"connect"> method in the L<Sys::Socket|SPVM::Sys::Socket> class with $addrlen.
 
-If succeed, returns 1.
-
 =head2 getpeername
 
 C<static method getpeername : L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr> ($sockfd : int);>
@@ -657,8 +633,6 @@ C<static method shutdown : void ($sockfd : int, $how : int);>
 
 Calls the L<shutdown|SPVM::Sys::Socket/"shutdown"> method in the L<Sys::Socket|SPVM::Sys::Socket> class.
 
-If succeed, returns 1.
-
 =head2 socket
 
 C<static method socket : void ($sockfd_ref : int*, $domain : int, $type : int, $protocol : int);>
@@ -675,8 +649,6 @@ Creates a new int array with the length 2 for the next argument $pair.
 Calls the L<socketpair|SPVM::Sys::Socket/"socketpair"> method in the L<Sys::Socket|SPVM::Sys::Socket> class with $pair,
 and the $$sock_fd1_ref is set the first element of $pair, and the $$sock_fd2_ref is set the second element of $pair, nad 
 
-If succeed, returns 1.
-
 =head2 setsockopt
 
 C<static method setsockopt : void ($sockfd : int, $level : int, $optname : int, $optval : object of string|Int);>
@@ -688,8 +660,6 @@ If $optval is the string type, a string that for the next argument $optval is cr
 Calls the L<getsockopt|SPVM::Sys::Socket/"getsockopt"> method in the L<Sys::Socket|SPVM::Sys::Socket> class
 with $optval and $optlen.
 
-If succeed, returns 1.
-
 Exceptions:
 
 $optval must be defined. Otherwise an exception is thrown.
@@ -713,8 +683,6 @@ C<static method truncate : void ($fd : int, $legnth : long);>
 
 Calls the L<ftruncate|SPVM::Sys::IO/"ftruncate"> method in the L<Sys::IO|SPVM::Sys::IO> class.
 
-If succeed, returns 1.
-
 =head2 sysread
 
 C<static method sysread : int ($fd : int, $buf : mutable string, $count : int, $buf_offset : int = 0);>
@@ -757,16 +725,12 @@ C<static method flock : void ($fd : int, $operation : int);>
 
 Calls the L<flock|SPVM::Sys::IO/"flock"> method in the L<Sys::IO|SPVM::Sys::IO> class.
 
-If succeed, returns 1.
-
 =head2 print
 
 C<static method print : void ($stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>, $string : string);>
 
 Calls the L<fwrite|SPVM::Sys::IO/"fwrite"> method in the L<Sys::IO|SPVM::Sys::IO> class given the length of $string.
 
-If succeed, returns 1.
-
 =head2 printf
 
 C<static method printf : void ($stream, $format : string, $args : object[])>
@@ -797,16 +761,12 @@ C<static method seek : void ($stream : L<Sys::IO::FileStream|SPVM::Sys::IO::File
 
 Calls the L<fseek|SPVM::Sys::IO/"fseek"> method in the L<Sys::IO|SPVM::Sys::IO> class.
 
-If succeed, returns 1.
-
 =head2 sysseek
 
 C<static method sysseek : long ($fd : int, $offset : long, $whence : int);>
 
 Calls the L<lseek|SPVM::Sys::IO/"lseek"> method in the L<Sys::IO|SPVM::Sys::IO> class.
 
-If succeed, returns 1.
-
 =head2 tell
 
 C<static method tell : long ($stream : L<Sys::IO::FileStream|SPVM::Sys::IO::FileStream>);>
@@ -841,8 +801,6 @@ C<static method chown : void ($owner : int, $group : int, $path : string);>
 
 Calls the L<chown|SPVM::Sys::IO/"chown"> method in the L<Sys::IO|SPVM::Sys::IO> class.
 
-If succeed, returns 1.
-
 =head2 fcntl
 
 C<static method fcntl : int ($fd : int, $command : int, $command_arg : object of Int|Sys::IO::Flock|object = undef);>
@@ -878,8 +836,6 @@ Calls the L<fopen|SPVM::Sys::IO/"fopen"> method in the L<Sys::IO|SPVM::Sys::IO>
 
 The return values is set to $stream_ref->[0].
 
-If succeed, returns 1.
-
 Exceptions:
 
 $stream_ref must be defined. Otherwise an exception is thrown.
@@ -915,8 +871,6 @@ Calls the L<fdopen|SPVM::Sys::IO/"fdopen"> method in the L<Sys::IO|SPVM::Sys::IO
 
 The return values is set to $stream_ref->[0].
 
-If succeed, returns 1.
-
 Exceptions:
 
 $stream_ref must be defined. Otherwise an exception is thrown.
@@ -1003,21 +957,11 @@ The exceptions thrown by the L<alarm|SPVM::Sys::Signal/"alarm"> method in the Sy
 
 =head2 pipe
 
-C<static method pipe : void ($pipe_fds : int[]);>
+C<static method pipe : void ($read_fd_ref : int*, $write_fd_ref : int*);>
 
-Windows:
+Opens a pair of pipes.
 
-Calls the L<_pipe|SPVM::Sys::Process/"_pipe"> method in the L<Sys::Process|SPVM::Sys::Process> class.
-
-If succeed, returns 1.
-
-Other OSs:
-
-Calls the L<pipe|SPVM::Sys::Process/"pipe"> method in the L<Sys::Process|SPVM::Sys::Process> class.
-
-Set C<FD_CLOEXEC> flag to the opened filed descriptors.
-
-If succeed, returns 1.
+If the system supports C<FD_CLOEXEC>, this flag is set to $read_fd_ref and $write_fd_ref using L</"fcntl">.
 
 =head1 Modules
 
