@@ -4,7 +4,11 @@ package SPVM::Sys::Time::Timeval;
 
 =head1 Name
 
-SPVM::Sys::Time::Timeval - struct timeval in C language
+SPVM::Sys::Time::Timeval - struct timeval in the C language
+
+=head1 Description
+
+The Sys::Time::Timeval class of L<SPVM> represents L<struct timeval|https://linux.die.net/man/2/gettimeofday> in the C language.
 
 =head1 Usage
   
@@ -12,62 +16,48 @@ SPVM::Sys::Time::Timeval - struct timeval in C language
   
   my $tv = Sys::Time::Timeval->new;
   
+  my $tv = Sys::Time::Timeval->new(5, 100_000);
+  
   my $tv_sec = $tv->tv_sec;
   $tv->set_tv_sec(12);
   
   my $tv_usec = $tv->tv_usec;
   $tv->set_tv_usec(34);
 
-=head1 Description
-
-C<Sys::Time::Timeval> represents C<struct timeval> in C<C language>.
-
-See L<gettimeofday(2) - Linux man page|https://linux.die.net/man/2/gettimeofday> about C<struct timeval> in Linux.
-
 =head1 Class Methods
 
 =head2 new
 
-C<static method new : L<Sys::Time::Timeval|SPVM::Sys::Time::Timeval> ()>
+C<static method new : L<Sys::Time::Timeval|SPVM::Sys::Time::Timeval> ($tv_sec : long = 0, $tv_usec : long = 0);>
 
 Creates a new C<Sys::Time::Timeval> object.
 
-  my $tv = Sys::Time::Timeval->new;
-
 =head1 Instance Methods
 
 =head2 tv_sec
 
-C<method tv_sec : long ()>
+C<method tv_sec : long ();>
 
 Gets C<tv_sec>.
 
-  my $tv_sec = $tv->tv_sec;
-
 =head2 set_tv_sec
 
-C<method set_tv_sec : void ($tv_sec : long)>
+C<method set_tv_sec : void ($tv_sec : long);>
 
 Sets C<tv_sec>.
 
-  $tv->set_tv_sec(12);
-
 =head2 tv_usec
   
-C<method tv_usec : long ()>
+C<method tv_usec : long ();>
 
 Gets C<tv_usec>.
 
-  my $tv_usec = $tv->tv_usec;
-
 =head2 set_tv_usec
 
-C<method set_tv_usec : void ($tv_usec : long)>
+C<method set_tv_usec : void ($tv_usec : long);>
 
 Sets C<tv_usec>.
 
-  $tv->set_tv_usec(34);
-
 =head1 Copyright & License
 
 Copyright (c) 2023 Yuki Kimoto
